#
# spec file for package python-authheaders
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-authheaders
Version:        0.15.3
Release:        bp156.2.1
Summary:        A library wrapping email authentication header verification and generation
License:        MIT
URL:            https://github.com/ValiMail/authentication-headers
Source:         https://files.pythonhosted.org/packages/source/a/authheaders/authheaders-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-authres >= 1.0.1
Requires:       python-dkimpy >= 0.7.1
Requires:       python-dnspython
Requires:       python-publicsuffix2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module authres >= 1.2.0}
BuildRequires:  %{python_module dkimpy >= 0.7.1}
BuildRequires:  %{python_module dnspython}
BuildRequires:  %{python_module publicsuffix2}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A library wrapping email authentication header verification and generation.

%prep
%setup -q -n authheaders-%{version}

%build
export LANG=en_US.UTF-8
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Remove binaries
rm %{buildroot}%{_bindir}/dmarc-policy-find
%python_expand rm %{buildroot}%{$python_sitelib}/authheaders/dmarcpolicyfind*.py*

%check
export LANG=en_US.UTF-8
%pytest

%files %{python_files}
%doc CHANGES README.md
%license COPYING
%{python_sitelib}/authheaders*

%changelog
* Thu Nov  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.15.3
  * https://github.com/ValiMail/authentication-headers/blob/0.15.3/CHANGES
    or the CHANGES file included in this package
* Tue Jun 13 2023 Dirk Müller <dmueller@suse.com>
- tag sle15 build for new python
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 0.14.1:
  - Bump version to fix pypi artifacts, no code changes
  - Use email.utils to parse the From header addresses (Thanks to Adam Clark
    for noting this issue and providing the fix) Fixes Github #5
  - Correct minimum authres version requirment in setup.py
  - Catch more errors.  Add DKIM temperror.  (Thanks to 'niftylettuce') Fixes
    Github #18
  - Skip DMARC records with no 'p' tag and don't raise an error (also thanks
    to 'niftylettuce')  Fixes Github #14
  - Fix issues with upper case characters in domain (Thanks to Mark Sapiro for
    root causing the issue and providing a fix for the domain name regex)
    Fixes Github #13
  - Include ARC result comment is A-R header field when ARC fails.  Fixes
    Github #12
  - Handle the case where no valid From is found.  Fixes Github #15
* Sun Apr 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.13.0:
  * Switch from the deprecated publicsuffix package to publicsuffix2
* Thu Jan 23 2020 pgajdos@suse.com
- do not require python-cffi for 15, it will be required by
  python-PyNaCl
* Fri Jan 10 2020 pgajdos@suse.com
- fix build in SLE-15: set en_US.UTF-8 encoding
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Wed Sep 25 2019 pgajdos@suse.com
- initial version 0.12.0, required by python-mailman [SLE-7686]
